
#ifndef _C14_ev667_
#define _C14_ev667_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1309_13464(EIF_REFERENCE, EIF_INTEGER_32);
extern void EIF_Minit667(void);

#ifdef __cplusplus
}
#endif

#endif
